@@ -21,16 +21,12 @@
 
 #include "player.h"
 
-#include <string.h>
-#include <limits.h>
-
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif
-
-#include <cstdlib>
 #include <iostream>
 
+#include <cstring>
+#include <climits>
+#include <cstdlib>
+
 using std::cout;
 using std::cerr;
 using std::endl;
@@ -425,22 +421,20 @@ int ConsolePlayer::args (int argc, const char *argv[])
         }
         if (!m_timer.valid)
         {
-#if !defined _WIN32 && defined HAVE_UNISTD_H
-            char buffer[PATH_MAX];
-#endif
-            const char *database = (m_iniCfg.sidplay2()).database;
             m_timer.length = (m_iniCfg.sidplay2()).playLength;
             if (m_driver.file)
                 m_timer.length = (m_iniCfg.sidplay2()).recordLength;
-#if !defined _WIN32 && defined HAVE_UNISTD_H
-            if (!database || *database == '\0')
-            {
-                snprintf(buffer, PATH_MAX, "%sSonglengths.txt", PKGDATADIR);
-                if (::access(buffer, R_OK) == 0)
-                    database = buffer;
-            }
+
+#if defined(WIN32) && defined(UNICODE)
+            // FIXME
+            char database[MAX_PATH];
+            int ret = wcstombs(database, (m_iniCfg.sidplay2()).database.c_str(), sizeof(database));
+            if (ret >= MAX_PATH)
+                database[0] = '\0';
+#else
+            const char *database = (m_iniCfg.sidplay2()).database.c_str();
 #endif
-            if (database && (*database != '\0'))
+            if (strlen(database) != 0)
             {   // Try loading the database specificed by the user
                 if (!m_database.open (database))
                 {
