@@ -43,6 +43,7 @@ using std::endl;
 #include "keyboard.h"
 #include "audio/AudioDrv.h"
 #include "audio/wav/WavFile.h"
+#include "ini/types.h"
 
 #include <sidplayfp/sidbuilder.h>
 #include <sidplayfp/SidInfo.h>
@@ -67,6 +68,65 @@ const char ConsolePlayer::HARDSID_ID[] = "HardSID";
 #endif
 
 
+uint8_t* loadRom(const SID_STRING &romPath, const int size)
+{
+    SID_IFSTREAM is(romPath.c_str(), std::ios::binary);
+
+    if (is.is_open())
+    {
+        try
+        {
+            uint8_t *buffer = new uint8_t[size];
+
+            is.read((char*)buffer, size);
+            if (!is.fail())
+            {
+                is.close();
+                return buffer;
+            }
+            delete [] buffer;
+        }
+        catch (std::bad_alloc const &ba) {}
+    }
+
+    return 0;
+}
+
+
+uint8_t* loadRom(const SID_STRING &romPath, const int size, const TCHAR defaultRom[])
+{
+    // Try to load given rom
+    if (!romPath.empty())
+    {
+        uint8_t* buffer = loadRom(romPath, size);
+        if (buffer)
+            return buffer;
+    }
+
+    // Fallback to default rom path
+    try
+    {
+        SID_STRING dataPath(utils::getDataPath());
+
+        dataPath.append(SEPARATOR).append(TEXT("sidplayfp")).append(SEPARATOR).append(defaultRom);
+
+#if !defined _WIN32 && defined HAVE_UNISTD_H
+        if (::access(dataPath.c_str(), R_OK) != 0)
+        {
+            dataPath = PKGDATADIR;
+            dataPath.append(defaultRom);
+        }
+#endif
+
+        return loadRom(dataPath, size);
+    }
+    catch (utils::error const &e)
+    {
+        return 0;
+    }
+}
+
+
 ConsolePlayer::ConsolePlayer (const char * const name) :
     Event("External Timer\n"),
     m_name(name),
@@ -113,24 +173,24 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         m_filter.filterCurve6581 = emulation.filterCurve6581;
         m_filter.filterCurve8580 = emulation.filterCurve8580;
 
-        if (emulation.engine)
+        if (!emulation.engine.empty())
         {
-            if (strcmp(emulation.engine, "RESIDFP") == 0)
+            if (emulation.engine.compare(TEXT("RESIDFP")) == 0)
             {
                 m_driver.sid    = EMU_RESIDFP;
             }
-            else if (strcmp(emulation.engine, "RESID") == 0)
+            else if (emulation.engine.compare(TEXT("RESID")) == 0)
             {
                 m_driver.sid    = EMU_RESID;
             }
 #ifdef HAVE_SIDPLAYFP_BUILDERS_HARDSID_H
-            else if (strcmp(emulation.engine, "HARDSID") == 0)
+            else if (emulation.engine.compare(TEXT("HARDSID")) == 0)
             {
                 m_driver.sid    = EMU_HARDSID;
                 m_driver.output = OUT_NULL;
             }
 #endif
-            else if (strcmp(emulation.engine, "NONE") == 0)
+            else if (emulation.engine.compare(TEXT("NONE")) == 0)
             {
                 m_driver.sid    = EMU_NONE;
             }
@@ -140,64 +200,15 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
     createOutput (OUT_NULL, NULL);
     createSidEmu (EMU_NONE);
 
-    uint8_t *kernalRom = loadRom((m_iniCfg.sidplay2()).kernalRom, 8192, "kernal");
-    uint8_t *basicRom = loadRom((m_iniCfg.sidplay2()).basicRom, 8192, "basic");
-    uint8_t *chargenRom = loadRom((m_iniCfg.sidplay2()).chargenRom, 4096, "chargen");
+    uint8_t *kernalRom = loadRom((m_iniCfg.sidplay2()).kernalRom, 8192, TEXT("kernal"));
+    uint8_t *basicRom = loadRom((m_iniCfg.sidplay2()).basicRom, 8192, TEXT("basic"));
+    uint8_t *chargenRom = loadRom((m_iniCfg.sidplay2()).chargenRom, 4096, TEXT("chargen"));
     m_engine.setRoms(kernalRom, basicRom, chargenRom);
     delete [] kernalRom;
     delete [] basicRom;
     delete [] chargenRom;
 }
 
-uint8_t* ConsolePlayer::loadRom(const char* romPath, const int size, const char defaultRom[])
-{
-    std::string dataPath;
-    try
-    {
-        dataPath = utils::getDataPath();
-    }
-    catch (utils::error const &e)
-    {
-        return 0;
-    }
-
-    dataPath.append("/sidplayfp/").append(defaultRom);
-
-#if !defined _WIN32 && defined HAVE_UNISTD_H
-    if (::access(dataPath.c_str(), R_OK) != 0)
-    {
-        dataPath = PKGDATADIR;
-        dataPath.append(defaultRom);
-    }
-#endif
-
-    std::ifstream is((romPath)?romPath:dataPath.c_str(), std::ios::binary);
-
-    if (is.fail())
-        goto error;
-    {
-        try
-        {
-            uint8_t *buffer = new uint8_t[size];
-
-            is.read((char*)buffer, size);
-            if (is.fail())
-                goto error;
-
-            is.close();
-            return buffer;
-        }
-        catch (std::bad_alloc const &ba)
-        {
-            goto error;
-        }
-    }
-
-error:
-    is.close();
-    return 0;
-}
-
 IAudio* ConsolePlayer::getWavFile(const SidTuneInfo *tuneInfo)
 {
     const char *title = m_outfile;
